@@ -1,5 +1,6 @@
 """Global settings module."""  # pylint: disable=bad-whitespace
 
+
 ######################
 #                    #
 # ONAP SERVICES URLS #
@@ -7,10 +8,14 @@
 ######################
 
 AAI_URL     = "https://aai.api.sparky.simpledemo.onap.org:30233"
-CDS_URL     = "https://portal.api.simpledemo.onap.org:30497"
+AAI_API_VERSION = "v16"
+CDS_URL     = "http://portal.api.simpledemo.onap.org:30449"
 MSB_URL     = "https://msb.api.simpledemo.onap.org:30283"
 SDC_BE_URL  = "https://sdc.api.be.simpledemo.onap.org:30204"
 SDC_FE_URL  = "https://sdc.api.fe.simpledemo.onap.org:30207"
 SDNC_URL    = "https://sdnc.api.simpledemo.onap.org:30267"
 SO_URL      = "http://so.api.simpledemo.onap.org:30277"
+SO_API_VERSION = "v7"
 VID_URL     = "https://vid.api.simpledemo.onap.org:30200"
+VID_API_VERSION = "/vid"
+CLAMP_URL   = "https://clamp.api.simpledemo.onap.org:30258"
